==> knative-model-6.6.2-sources.jar: io/fabric8/knative/sources/v1/ApiServerSourceSpecFluent.java <==
package io.fabric8.knative.sources.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;

 /**
  * Generated
  */
public interface ApiServerSourceSpecFluent<A extends ApiServerSourceSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCeOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public CloudEventOverrides getCeOverrides();
  public CloudEventOverrides buildCeOverrides();
  public A withCeOverrides(CloudEventOverrides ceOverrides);
  public Boolean hasCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
  public ApiServerSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildOwner instead.
   * @return The buildable object.
   */
  @Deprecated
  public APIVersionKind getOwner();
  public APIVersionKind buildOwner();
  public A withOwner(APIVersionKind owner);
  public Boolean hasOwner();
  public A withNewOwner(String apiVersion,String kind);
  public ApiServerSourceSpecFluent.OwnerNested<A> withNewOwner();
  public ApiServerSourceSpecFluent.OwnerNested<A> withNewOwnerLike(APIVersionKind item);
  public ApiServerSourceSpecFluent.OwnerNested<A> editOwner();
  public ApiServerSourceSpecFluent.OwnerNested<A> editOrNewOwner();
  public ApiServerSourceSpecFluent.OwnerNested<A> editOrNewOwnerLike(APIVersionKind item);
  public A addToResources(Integer index,APIVersionKindSelector item);
  public A setToResources(Integer index,APIVersionKindSelector item);
  public A addToResources(io.fabric8.knative.sources.v1.APIVersionKindSelector... items);
  public A addAllToResources(Collection<APIVersionKindSelector> items);
  public A removeFromResources(io.fabric8.knative.sources.v1.APIVersionKindSelector... items);
  public A removeAllFromResources(Collection<APIVersionKindSelector> items);
  public A removeMatchingFromResources(Predicate<APIVersionKindSelectorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIVersionKindSelector> getResources();
  public List<APIVersionKindSelector> buildResources();
  public APIVersionKindSelector buildResource(Integer index);
  public APIVersionKindSelector buildFirstResource();
  public APIVersionKindSelector buildLastResource();
  public APIVersionKindSelector buildMatchingResource(Predicate<APIVersionKindSelectorBuilder> predicate);
  public Boolean hasMatchingResource(Predicate<APIVersionKindSelectorBuilder> predicate);
  public A withResources(List<APIVersionKindSelector> resources);
  public A withResources(io.fabric8.knative.sources.v1.APIVersionKindSelector... resources);
  public Boolean hasResources();
  public ApiServerSourceSpecFluent.ResourcesNested<A> addNewResource();
  public ApiServerSourceSpecFluent.ResourcesNested<A> addNewResourceLike(APIVersionKindSelector item);
  public ApiServerSourceSpecFluent.ResourcesNested<A> setNewResourceLike(Integer index,APIVersionKindSelector item);
  public ApiServerSourceSpecFluent.ResourcesNested<A> editResource(Integer index);
  public ApiServerSourceSpecFluent.ResourcesNested<A> editFirstResource();
  public ApiServerSourceSpecFluent.ResourcesNested<A> editLastResource();
  public ApiServerSourceSpecFluent.ResourcesNested<A> editMatchingResource(Predicate<APIVersionKindSelectorBuilder> predicate);
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getSink();
  public Destination buildSink();
  public A withSink(Destination sink);
  public Boolean hasSink();
  public ApiServerSourceSpecFluent.SinkNested<A> withNewSink();
  public ApiServerSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
  public ApiServerSourceSpecFluent.SinkNested<A> editSink();
  public ApiServerSourceSpecFluent.SinkNested<A> editOrNewSink();
  public ApiServerSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
  public interface CeOverridesNested<N> extends Nested<N>,CloudEventOverridesFluent<ApiServerSourceSpecFluent.CeOverridesNested<N>>{
    public N and();
    public N endCeOverrides();
    
  }
  public interface OwnerNested<N> extends Nested<N>,APIVersionKindFluent<ApiServerSourceSpecFluent.OwnerNested<N>>{
    public N and();
    public N endOwner();
    
  }
  public interface ResourcesNested<N> extends Nested<N>,APIVersionKindSelectorFluent<ApiServerSourceSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResource();
    
  }
  public interface SinkNested<N> extends Nested<N>,DestinationFluent<ApiServerSourceSpecFluent.SinkNested<N>>{
    public N and();
    public N endSink();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/sources/v1/ApiServerSourceSpecFluent.java <==
package io.fabric8.knative.sources.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface ApiServerSourceSpecFluent<A extends ApiServerSourceSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCeOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public CloudEventOverrides getCeOverrides();
  public CloudEventOverrides buildCeOverrides();
  public A withCeOverrides(CloudEventOverrides ceOverrides);
  public Boolean hasCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
  public ApiServerSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
  public ApiServerSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildOwner instead.
   * @return The buildable object.
   */
  @Deprecated
  public APIVersionKind getOwner();
  public APIVersionKind buildOwner();
  public A withOwner(APIVersionKind owner);
  public Boolean hasOwner();
  public A withNewOwner(String apiVersion,String kind);
  public ApiServerSourceSpecFluent.OwnerNested<A> withNewOwner();
  public ApiServerSourceSpecFluent.OwnerNested<A> withNewOwnerLike(APIVersionKind item);
  public ApiServerSourceSpecFluent.OwnerNested<A> editOwner();
  public ApiServerSourceSpecFluent.OwnerNested<A> editOrNewOwner();
  public ApiServerSourceSpecFluent.OwnerNested<A> editOrNewOwnerLike(APIVersionKind item);
  public A addToResources(int index,APIVersionKindSelector item);
  public A setToResources(int index,APIVersionKindSelector item);
  public A addToResources(io.fabric8.knative.sources.v1.APIVersionKindSelector... items);
  public A addAllToResources(Collection<APIVersionKindSelector> items);
  public A removeFromResources(io.fabric8.knative.sources.v1.APIVersionKindSelector... items);
  public A removeAllFromResources(Collection<APIVersionKindSelector> items);
  public A removeMatchingFromResources(Predicate<APIVersionKindSelectorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIVersionKindSelector> getResources();
  public List<APIVersionKindSelector> buildResources();
  public APIVersionKindSelector buildResource(int index);
  public APIVersionKindSelector buildFirstResource();
  public APIVersionKindSelector buildLastResource();
  public APIVersionKindSelector buildMatchingResource(Predicate<APIVersionKindSelectorBuilder> predicate);
  public Boolean hasMatchingResource(Predicate<APIVersionKindSelectorBuilder> predicate);
  public A withResources(List<APIVersionKindSelector> resources);
  public A withResources(io.fabric8.knative.sources.v1.APIVersionKindSelector... resources);
  public Boolean hasResources();
  public ApiServerSourceSpecFluent.ResourcesNested<A> addNewResource();
  public ApiServerSourceSpecFluent.ResourcesNested<A> addNewResourceLike(APIVersionKindSelector item);
  public ApiServerSourceSpecFluent.ResourcesNested<A> setNewResourceLike(int index,APIVersionKindSelector item);
  public ApiServerSourceSpecFluent.ResourcesNested<A> editResource(int index);
  public ApiServerSourceSpecFluent.ResourcesNested<A> editFirstResource();
  public ApiServerSourceSpecFluent.ResourcesNested<A> editLastResource();
  public ApiServerSourceSpecFluent.ResourcesNested<A> editMatchingResource(Predicate<APIVersionKindSelectorBuilder> predicate);
  public String getServiceAccountName();
  public A withServiceAccountName(String serviceAccountName);
  public Boolean hasServiceAccountName();
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getSink();
  public Destination buildSink();
  public A withSink(Destination sink);
  public Boolean hasSink();
  public ApiServerSourceSpecFluent.SinkNested<A> withNewSink();
  public ApiServerSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
  public ApiServerSourceSpecFluent.SinkNested<A> editSink();
  public ApiServerSourceSpecFluent.SinkNested<A> editOrNewSink();
  public ApiServerSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
  public interface CeOverridesNested<N> extends Nested<N>,CloudEventOverridesFluent<ApiServerSourceSpecFluent.CeOverridesNested<N>>{
    public N and();
    public N endCeOverrides();
    
  }
  public interface OwnerNested<N> extends Nested<N>,APIVersionKindFluent<ApiServerSourceSpecFluent.OwnerNested<N>>{
    public N and();
    public N endOwner();
    
  }
  public interface ResourcesNested<N> extends Nested<N>,APIVersionKindSelectorFluent<ApiServerSourceSpecFluent.ResourcesNested<N>>{
    public N and();
    public N endResource();
    
  }
  public interface SinkNested<N> extends Nested<N>,DestinationFluent<ApiServerSourceSpecFluent.SinkNested<N>>{
    public N and();
    public N endSink();
    
  }
  
}
